/*
 * Joey and its relative products are published under the terms
 * of the Apache Software License.
 */
/*
 * Created on 2004/01/05
 */
package org.asyrinx.joey.tapestry.components.stative;

import java.util.HashMap;
import java.util.Map;

import org.apache.tapestry.AbstractComponent;
import org.apache.tapestry.ApplicationRuntimeException;
import org.apache.tapestry.IComponent;
import org.apache.tapestry.IMarkupWriter;
import org.apache.tapestry.IPage;
import org.apache.tapestry.IRequestCycle;
import org.apache.tapestry.IScript;
import org.apache.tapestry.html.Body;
import org.asyrinx.brownie.tapestry.script.ScriptUtils;
import org.asyrinx.brownie.tapestry.util.ComponentUtils;

/**
 * @author akima
 */
public class PageEditingControl extends AbstractComponent {

	/**
	 * @see org.apache.tapestry.BaseComponent#renderComponent(org.apache.tapestry.IMarkupWriter, org.apache.tapestry.IRequestCycle)
	 */
	protected void renderComponent(IMarkupWriter writer, IRequestCycle cycle) {
		//super.renderComponent(writer, cycle);
		final IPage page = getPage();
		if (page instanceof BaseEditPage) {
			final BaseEditPage editPage = (BaseEditPage) page;
			if (!editPage.isEditing()) {
				final Body body = getBodyComponent(page);
				final IScript script = loadScript(this);
				addScript(cycle, script, body);
			}
		}
	}

	protected Body getBodyComponent(IPage page) {
		final IComponent component =
			ComponentUtils.searchBottomByClass(page, Body.class);
		if (component instanceof Body)
			return (Body) component;
		else
			throw new ApplicationRuntimeException(
				"must-have-Body-component",
				this,
				null,
				null);
	}

	/**
	 * @see org.asyrinx.brownie.tapestry.components.link.AbstractScriptLinkRenderer#addScript(org.apache.tapestry.IRequestCycle, org.apache.tapestry.IScript, org.apache.tapestry.html.Body)
	 */
	protected void addScript(IRequestCycle cycle, IScript script, Body body) {
		final Map symbols = new HashMap();
		script.execute(cycle, body, symbols);
	}

	private static final String SCRIPT_NAME = "PageEditingControl.script";

	private IScript script = null;

	/**
	 * @return
	 */
	protected IScript loadScript(IComponent component) {
		if (script == null)
			script = ScriptUtils.loadScript(component, SCRIPT_NAME);
		return script;
	}

}
